import { Column } from '@antv/g2plot';
import { GraphinContext } from '@antv/graphin';
import { groupBy } from 'lodash';
import React, { useContext, useEffect, useRef } from 'react';
import { ITEM_STATE } from './registerMeta';
import $i18n from '../i18n';
var plot = null;
var dataTypeLocaleMap = {};
var ResultTable = function ResultTable(_ref) {
  var data = _ref.data,
    currentAlgo = _ref.currentAlgo,
    edgeType = _ref.edgeType;
  var _useContext = useContext(GraphinContext),
    graph = _useContext.graph;
  var plotRef = useRef(null);
  useEffect(function () {
    var plotData = getPlotData();
    if (plot) {
      plot.destroy();
    }
    //@ts-ignore
    plot = new Column(plotRef.current, {
      data: plotData,
      xField: 'value',
      yField: 'count',
      maxColumnWidth: 60,
      colorField: 'count',
      legend: {
        layout: 'horizontal',
        position: 'bottom',
        offsetY: 4,
        maxRow: 2
      },
      label: {
        position: 'middle',
        style: {
          fill: '#FFFFFF',
          opacity: 0.6
        }
      },
      xAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.NodeImportance.resultPlot.ImportanceValue',
            dm: '重要性值'
          }),
          position: 'end',
          offset: 14,
          style: {
            stroke: '#fff',
            lineWidth: 2,
            fontWeight: 400
          }
        }
      },
      yAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.NodeImportance.resultPlot.NumberOfNodes',
            dm: '节点数量'
          }),
          position: 'end',
          autoRotate: false,
          spacing: -55,
          style: {
            stroke: '#fff',
            lineWidth: 2,
            fontWeight: 400
          }
        }
      }
    });
    plot.render();
    plot.on('interval:mouseleave', clearActiveItems);
    plot.on('interval:mouseenter', onEnterColumn);
  }, [data]);
  var getPlotData = function getPlotData() {
    var _a;
    var plotData = [];
    var countMap = groupBy(((_a = data.node) === null || _a === void 0 ? void 0 : _a.data) || [], 'value');
    Object.keys(countMap).forEach(function (key) {
      plotData.push({
        //@ts-ignore
        value: key,
        //@ts-ignore
        count: countMap[key].length
      });
    });
    return plotData;
  };
  var clearActiveItems = function clearActiveItems() {
    var activateItems = graph.findAllByState('node', ITEM_STATE.Active).concat(graph.findAllByState('edge', ITEM_STATE.Active));
    activateItems.forEach(function (item) {
      graph.setItemState(item, ITEM_STATE.Active, false);
    });
  };
  var onEnterColumn = function onEnterColumn(e) {
    var _a, _b, _c, _d, _e;
    if (!((_a = e.data) === null || _a === void 0 ? void 0 : _a.data)) {
      return;
    }
    var value = (_c = (_b = e.data) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.value;
    clearActiveItems();
    var nodes = data.node.data.filter(function (node) {
      return +node.value === +value;
    });
    var nodeIds = nodes.map(function (node) {
      return node.id;
    });
    nodes.forEach(function (node) {
      var item = graph.findById(node.id);
      if (item) {
        graph.setItemState(item, ITEM_STATE.Active, true);
      }
    });
    // 若未关系属性重要性, 同时高亮该节点相关的被映射过的边
    if (currentAlgo === 'edge-property') {
      (_e = (_d = data.edge) === null || _d === void 0 ? void 0 : _d.data) === null || _e === void 0 ? void 0 : _e.forEach(function (edge) {
        var edgeItem = graph.findById(edge.id);
        if (!edgeItem) {
          return;
        }
        var edgeModel = edgeItem.getModel();
        if (nodeIds.includes(edgeModel.source) || nodeIds.includes(edgeModel.target)) {
          graph.setItemState(edgeItem, ITEM_STATE.Active, true);
        }
      });
    }
  };
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "plot-wrapper",
    ref: plotRef
  }));
};
export default ResultTable;